package broker

import "github.com/pivotal-cf/brokerapi"

func (b *Broker) Services() []brokerapi.Service {
	servicePlans := []brokerapi.ServicePlan{}
	for _, plan := range b.serviceOffering.Plans {

		planCosts := []brokerapi.ServicePlanCost{}
		for _, cost := range plan.Metadata.Costs {
			planCosts = append(planCosts, brokerapi.ServicePlanCost{cost.Amount, cost.Unit})
		}

		servicePlan := brokerapi.ServicePlan{
			ID:          plan.ID,
			Name:        plan.Name,
			Description: plan.Description,
			Metadata: &brokerapi.ServicePlanMetadata{
				DisplayName: plan.Metadata.DisplayName,
				Bullets:     plan.Metadata.Bullets,
				Costs:       planCosts,
			},
		}
		servicePlans = append(servicePlans, servicePlan)
	}

	return []brokerapi.Service{
		{
			ID:            b.serviceOffering.ID,
			Name:          b.serviceOffering.Name,
			Description:   b.serviceOffering.Description,
			Bindable:      b.serviceOffering.Bindable,
			PlanUpdatable: b.serviceOffering.PlanUpdatable,
			Plans:         servicePlans,
			Metadata: &brokerapi.ServiceMetadata{
				DisplayName:         b.serviceOffering.Metadata.DisplayName,
				ImageUrl:            b.serviceOffering.Metadata.ImageURL,
				LongDescription:     b.serviceOffering.Metadata.LongDescription,
				ProviderDisplayName: b.serviceOffering.Metadata.ProviderDisplayName,
				DocumentationUrl:    b.serviceOffering.Metadata.DocumentationURL,
				SupportUrl:          b.serviceOffering.Metadata.SupportURL,
			},
			Requires: requiredPermissions(b.serviceOffering.Requires),
			Tags:     b.serviceOffering.Tags,
		},
	}
}

func requiredPermissions(permissions []string) []brokerapi.RequiredPermission {
	brokerPermissions := []brokerapi.RequiredPermission{}
	for _, permission := range permissions {
		brokerPermissions = append(brokerPermissions, brokerapi.RequiredPermission(permission))
	}
	return brokerPermissions
}
